package com.fs.his.service;

import java.util.List;
import java.util.Map;

import com.fs.his.domain.FsPackageCate;
import com.fs.his.param.FsPackageCateUParam;
import com.fs.his.vo.OptionsVO;
import org.springframework.cache.annotation.CacheEvict;

/**
 * 套餐包分类Service接口
 *
 * @author fs
 * @date 2024-05-08
 */
public interface IFsPackageCateService
{
    /**
     * 查询套餐包分类
     *
     * @param cateId 套餐包分类主键
     * @return 套餐包分类
     */
    public FsPackageCate selectFsPackageCateByCateId(Long cateId);

    /**
     * 查询套餐包分类列表
     *
     * @param fsPackageCate 套餐包分类
     * @return 套餐包分类集合
     */
    public List<FsPackageCate> selectFsPackageCateList(FsPackageCateUParam fsPackageCate);

    /**
     * 新增套餐包分类
     *
     * @param fsPackageCate 套餐包分类
     * @return 结果
     */
    public int insertFsPackageCate(FsPackageCate fsPackageCate);

    /**
     * 修改套餐包分类
     *
     * @param fsPackageCate 套餐包分类
     * @return 结果
     */
    public int updateFsPackageCate(FsPackageCate fsPackageCate);

    /**
     * 批量删除套餐包分类
     *
     * @param cateIds 需要删除的套餐包分类主键集合
     * @return 结果
     */
    public int deleteFsPackageCateByCateIds(Long[] cateIds);

    /**
     * 删除套餐包分类信息
     *
     * @param cateId 套餐包分类主键
     * @return 结果
     */
    public int deleteFsPackageCateByCateId(Long cateId);

    Map selectFsArticleCateAllList();
    List<OptionsVO> selectCateList();

}
